@@ -4,11 +4,12 @@ use Mojo::Base -base;
 use Carp qw(croak shortmess);
 use DBI 'SQL_VARCHAR';
 use Mojo::JSON 'to_json';
+use Mojo::Promise;
 use Mojo::SQLite::Results;
 use Mojo::SQLite::Transaction;
 use Mojo::Util 'monkey_patch';
 
-our $VERSION = '3.004';
+our $VERSION = '3.005';
 
 our @CARP_NOT = qw(Mojo::SQLite::Migrations);
 
@@ -20,6 +21,10 @@ for my $name (qw(delete insert select update)) {
     my ($self, @cb) = (shift, ref $_[-1] eq 'CODE' ? pop : ());
     return $self->query($self->sqlite->abstract->$name(@_), @cb);
   };
+  monkey_patch __PACKAGE__, "${name}_p", sub {
+    my $self = shift;
+    return $self->query_p($self->sqlite->abstract->$name(@_));
+  };
 }
 
 sub DESTROY {
@@ -86,6 +91,13 @@ sub query {
   return $self;
 }
 
+sub query_p {
+  my $self    = shift;
+  my $promise = Mojo::Promise->new;
+  $self->query(@_ => sub { $_[1] ? $promise->reject($_[1]) : $promise->resolve($_[2]) });
+  return $promise;
+}
+
 sub tables {
   my @tables = shift->dbh->tables(undef, undef, undef, 'TABLE,VIEW,LOCAL TEMPORARY');
   my %names; # Deduplicate returned temporary table indexes
@@ -201,8 +213,7 @@ L<SQL::Abstract> object) and execute it with L</"query">. You can also append a
 callback for API compatibility with L<Mojo::Pg>; the query is still executed in
 a blocking manner.
 
-  $db->delete(some_table => sub {
-    my ($db, $err, $results) = @_;
+  $db->delete(some_table => sub ($db, $err, $results) {
     ...
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
@@ -219,6 +230,20 @@ L<SQL::Abstract>.
   # "delete from some_table where foo like '%test%'"
   $db->delete('some_table', {foo => {-like => '%test%'}});
 
+=head2 delete_p
+
+  my $promise = $db->delete_p($table, \%where, \%options);
+
+Same as L</"delete"> but returns a L<Mojo::Promise> object instead of accepting
+a callback. For API compatibility with L<Mojo::Pg>; the query is still executed
+in a blocking manner.
+
+  $db->delete_p('some_table')->then(sub ($results) {
+    ...
+  })->catch(sub ($err) {
+    ...
+  })->wait;
+
 =head2 disconnect
 
   $db->disconnect;
@@ -234,8 +259,7 @@ L<SQL::Abstract> object) and execute it with L</"query">. You can also append a
 callback for API compatibility with L<Mojo::Pg>; the query is still executed in
 a blocking manner.
 
-  $db->insert(some_table => {foo => 'bar'} => sub {
-    my ($db, $err, $results) = @_;
+  $db->insert(some_table => {foo => 'bar'} => sub ($db, $err, $results) {
     ...
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
@@ -246,6 +270,20 @@ L<SQL::Abstract>.
   # "insert into some_table (foo, baz) values ('bar', 'yada')"
   $db->insert('some_table', {foo => 'bar', baz => 'yada'});
 
+=head2 insert_p
+
+  my $promise = $db->insert_p($table, \@values || \%fieldvals, \%options);
+
+Same as L</"insert"> but returns a L<Mojo::Promise> object instead of accepting
+a callback. For API compatibility with L<Mojo::Pg>; the query is still executed
+in a blocking manner.
+
+  $db->insert_p(some_table => {foo => 'bar'})->then(sub ($results) {
+    ...
+  })->catch(sub ($err) {
+    ...
+  })->wait;
+
 =head2 ping
 
   my $bool = $db->ping;
@@ -267,8 +305,7 @@ increase the performance of future queries. You can also append a callback for
 API compatibility with L<Mojo::Pg>; the query is still executed in a blocking
 manner.
 
-  $db->query('insert into foo values (?, ?, ?)' => @values => sub {
-    my ($db, $err, $results) = @_;
+  $db->query('insert into foo values (?, ?, ?)' => @values => sub ($db, $err, $results) {
     ...
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
@@ -287,6 +324,20 @@ with L<Mojo::JSON/"from_json">.
   $db->query('select ? as foo', {json => {bar => 'I ♥ SQLite!'}})
     ->expand(json => 'foo')->hash->{foo}{bar};
 
+=head2 query_p
+
+  my $promise = $db->query_p('SELECT * FROM foo');
+
+Same as L</"query"> but returns a L<Mojo::Promise> object instead of accepting
+a callback. For API compatibility with L<Mojo::Pg>; the query is still executed
+in a blocking manner.
+
+  $db->query_p('INSERT INTO foo VALUES (?, ?, ?)' => @values)->then(sub ($results) {
+    ...
+  })->catch(sub ($err) {
+    ...
+  })->wait;
+
 =head2 select
 
   my $results = $db->select($source, $fields, $where, $order);
@@ -296,8 +347,7 @@ L<SQL::Abstract> object) and execute it with L</"query">. You can also append a
 callback for API compatibility with L<Mojo::Pg>; the query is still executed in
 a blocking manner.
 
-  $db->select(some_table => ['foo'] => {bar => 'yada'} => sub {
-    my ($db, $err, $results) = @_;
+  $db->select(some_table => ['foo'] => {bar => 'yada'} => sub ($db, $err, $results) {
     ...
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
@@ -320,6 +370,20 @@ L<SQL::Abstract>.
   # "select * from some_table where foo like '%test%'"
   $db->select('some_table', undef, {foo => {-like => '%test%'}});
 
+=head2 select_p
+
+  my $promise = $db->select_p($source, $fields, $where, \%options);
+
+Same as L</"select"> but returns a L<Mojo::Promise> object instead of accepting
+a callback. For API compatibility with L<Mojo::Pg>; the query is still executed
+in a blocking manner.
+
+  $db->select_p(some_table => ['foo'] => {bar => 'yada'})->then(sub ($results) {
+    ...
+  })->catch(sub ($err) {
+    ...
+  })->wait;
+
 =head2 tables
 
   my $tables = $db->tables;
@@ -342,8 +406,7 @@ L<SQL::Abstract> object) and execute it with L</"query">. You can also append a
 callback for API compatibility with L<Mojo::Pg>; the query is still executed in
 a blocking manner.
 
-  $db->update(some_table => {foo => 'baz'} => {foo => 'bar'} => sub {
-    my ($db, $err, $results) = @_;
+  $db->update(some_table => {foo => 'baz'} => {foo => 'bar'} => sub ($db, $err, $results) {
     ...
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
@@ -357,6 +420,20 @@ L<SQL::Abstract>.
   # "update some_table set foo = 'bar' where foo like '%test%'"
   $db->update('some_table', {foo => 'bar'}, {foo => {-like => '%test%'}});
 
+=head2 update_p
+
+  my $promise = $db->update_p($table, \%fieldvals, \%where, \%options);
+
+Same as L</"update"> but returns a L<Mojo::Promise> object instead of accepting
+a callback. For API compatibility with L<Mojo::Pg>; the query is still executed
+in a blocking manner.
+
+  $db->update_p(some_table => {foo => 'baz'} => {foo => 'bar'})->then(sub ($results) {
+    ...
+  })->catch(sub ($err) {
+    ...
+  })->wait;
+
 =head1 BUGS
 
 Report any issues on the public bugtracker.
